@@ -1,12 +1,13 @@
 package Acme::OSDc;
 
-my %OSDc = &{"Acme::Ook::O?"};
-use strict;
-use warnings;
-
 use base 'Acme::Ook';
 
-our $VERSION = '1.00';
+my %OSDc = &{"Acme::Ook::O?"};
+
+use strict;
+use warnings;
+
+our $VERSION = '1.01';
 
 sub _compile {
     shift;
@@ -25,6 +26,13 @@ Acme::OSDc - the OSDc programming language
 
 =head1 SYNOPSIS
 
+	use Acme::OSDc;
+	my $OSDc = Acme::OSDc->new;
+	
+	my $compiled = $OSDc->compile($file);
+	
+	eval $compiled;
+
 =head1 DESCRIPTION
 
 The I<OSDc> programming language is a transformation of the
